/***************************************************************
 * Name:      autocompletar.cpp
 * Purpose:   Code for Dialog boxSizer
 * Author:    Salvador Pozo (salvapozo@gmail.com)
 * Created:   2024-10-31
 * Copyright: Salvador Pozo (https://conclase.net)
 * License:
 **************************************************************/

#ifdef WX_PRECOMP
#include "wx_pch.h"
#endif

#include "autocompletar.h"

BEGIN_EVENT_TABLE(autocompletar, wxDialog)
    EVT_CLOSE(autocompletar::OnClose)
    EVT_BUTTON(wxID_OK, autocompletar::OnOk)
END_EVENT_TABLE()

class colorCompleter : public wxTextCompleterSimple
{
public:
    virtual void GetCompletions(const wxString& prefix, wxArrayString& res)
    {
        const wxString firstWord = prefix.BeforeFirst(' ');
        if ( firstWord == "verde" )
        {
            res.push_back("verde claro");
            res.push_back("verde oscuro");
        }
        else if ( firstWord == "azul" )
        {
            res.push_back("azul claro");
            res.push_back("azul oscuro");
        }
        else
        {
            res.push_back("amarillo");
            res.push_back("azul");
            res.push_back("blanco");
            res.push_back("naranja");
            res.push_back("rojo");
            res.push_back("rosa");
            res.push_back("negro");
            res.push_back("verde");
            res.push_back("violeta");
        }
    }
};

autocompletar::autocompletar(wxWindow *wnd, datosAutocompletar &data)
    : wxDialog(wnd, -1, _T("Ejemplo edición autocompletar")),
      datos(data),
      valTexto(wxFILTER_NONE, &datos.texto)
{
    wxBoxSizer *boxVertical;
    wxBoxSizer *boxHorizontal;

    boxVertical = new wxBoxSizer(wxVERTICAL);

    boxHorizontal = new wxBoxSizer(wxHORIZONTAL);
    boxHorizontal->Add(new wxStaticText(this, wxID_ANY, _T("&Color:")), wxSizerFlags().Border());
    ctrlTexto = new wxTextCtrl(this, idTexto, wxEmptyString, wxDefaultPosition, wxSize(200, wxDefaultCoord), 0, valTexto);
    ctrlTexto->AutoComplete(new colorCompleter);
    boxHorizontal->Add(ctrlTexto, wxSizerFlags().Border());
    boxVertical->Add(boxHorizontal, wxSizerFlags().Border(wxTOP).Right());

    boxHorizontal = new wxBoxSizer(wxHORIZONTAL);

    boxHorizontal->Add(CreateStdDialogButtonSizer(wxOK | wxCANCEL), wxSizerFlags().Border());
    boxVertical->Add(boxHorizontal, wxSizerFlags().Border(wxTOP).Right());

    SetSizerAndFit(boxVertical);
}

void autocompletar::OnClose(wxCloseEvent &event)
{
    Destroy();
}

void autocompletar::OnOk(wxCommandEvent &event)
{
    datos.texto = ctrlTexto->GetValue();
    Destroy();
}
