/***************************************************************
 * Name:      autocompletar2.cpp
 * Purpose:   Code for Dialog boxSizer
 * Author:    Salvador Pozo (salvapozo@gmail.com)
 * Created:   2024-10-31
 * Copyright: Salvador Pozo (https://conclase.net)
 * License:
 **************************************************************/

#ifdef WX_PRECOMP
#include "wx_pch.h"
#endif

#include <cstring>
#include <sqlite3.h>

#include "autocompletar2.h"

BEGIN_EVENT_TABLE(autocompletar2, wxDialog)
    EVT_CLOSE(autocompletar2::OnClose)
    EVT_BUTTON(wxID_OK, autocompletar2::OnOk)
END_EVENT_TABLE()

class palabrasCompleter : public wxTextCompleter
{
    public:
        virtual bool Start(const wxString& prefix)
        {
            int rc;

            if(prefix.size() <= 3) return false; // No completar palabras de tres letras o menos
            rc = sqlite3_open("palabras.db", &db);
            consulta = _("SELECT palabra FROM palabras WHERE palabra LIKE '") + prefix + "%';";
            rc = sqlite3_prepare_v2(db, static_cast<const char*>(consulta), -1, &ppStmt, NULL);
            if( rc!=SQLITE_OK ) return false;

            return true;
        }
        virtual wxString GetNext() {
            if(SQLITE_ROW == sqlite3_step(ppStmt)) {
                const char *p = reinterpret_cast<const char*>(sqlite3_column_text(ppStmt, 0));
                return wxString::FromUTF8(p);
            } else {
                sqlite3_finalize(ppStmt);
                sqlite3_close(db);
                return wxString(_T(""));
            }
        }
    private:
        sqlite3 *db;
        sqlite3_stmt *ppStmt;
        wxString consulta;
};

autocompletar2::autocompletar2(wxWindow *wnd, datosAutocompletar2 &data)
    : wxDialog(wnd, -1, _T("Ejemplo edición autocompletar")),
      datos(data),
      valTexto(wxFILTER_NONE, &datos.texto)
{
    wxBoxSizer *boxVertical;
    wxBoxSizer *boxHorizontal;

    boxVertical = new wxBoxSizer(wxVERTICAL);

    boxHorizontal = new wxBoxSizer(wxHORIZONTAL);
    boxHorizontal->Add(new wxStaticText(this, wxID_ANY, _T("&Palabra:")), wxSizerFlags().Border());
    ctrlTexto = new wxTextCtrl(this, idTexto, wxEmptyString, wxDefaultPosition, wxSize(200, wxDefaultCoord), 0, valTexto);
    ctrlTexto->AutoComplete(new palabrasCompleter);
    boxHorizontal->Add(ctrlTexto, wxSizerFlags().Border());
    boxVertical->Add(boxHorizontal, wxSizerFlags().Border(wxTOP).Right());

    boxHorizontal = new wxBoxSizer(wxHORIZONTAL);

    boxHorizontal->Add(CreateStdDialogButtonSizer(wxOK | wxCANCEL), wxSizerFlags().Border());
    boxVertical->Add(boxHorizontal, wxSizerFlags().Border(wxTOP).Right());

    SetSizerAndFit(boxVertical);
}

void autocompletar2::OnClose(wxCloseEvent &event)
{
    Destroy();
}

void autocompletar2::OnOk(wxCommandEvent &event)
{
    datos.texto = ctrlTexto->GetValue();
    Destroy();
}
