/***************************************************************
 * Name:      multilinea.cpp
 * Purpose:   Code for Dialog boxSizer
 * Author:    Salvador Pozo (salvapozo@gmail.com)
 * Created:   2024-04-11
 * Copyright: Salvador Pozo (https://conclase.net)
 * License:
 **************************************************************/

#ifdef WX_PRECOMP
#include "wx_pch.h"
#endif

#include "multilinea.h"

BEGIN_EVENT_TABLE(multilinea, wxDialog)
    EVT_CLOSE(multilinea::OnClose)
    EVT_BUTTON(wxID_OK, multilinea::OnOk)
    EVT_BUTTON(idLoad, multilinea::OnCargar)
    EVT_BUTTON(idSelectAll, multilinea::OnTodo)
    EVT_BUTTON(idSelectNone, multilinea::OnNada)
    EVT_BUTTON(idValue, multilinea::OnValue)
    EVT_BUTTON(idRango, multilinea::OnRango)
    EVT_TEXT_URL(idTexto, multilinea::OnURL)
END_EVENT_TABLE()

multilinea::multilinea(wxWindow *wnd, datosTextoMultilinea &data)
    : wxDialog(wnd, -1, _T("Ejemplo edición de texto")),
      datos(data),
      valTexto(wxFILTER_NONE, &datos.texto)
{
    wxBoxSizer *boxVertical;
    wxBoxSizer *boxHorizontal;

    boxVertical = new wxBoxSizer(wxVERTICAL);

    boxHorizontal = new wxBoxSizer(wxHORIZONTAL);
    boxHorizontal->Add(new wxStaticText(this, wxID_ANY, _T("&Texto:")), wxSizerFlags().Border());
    ctrlTexto = new wxTextCtrl(this, idTexto, wxEmptyString, wxDefaultPosition, wxSize(200, 250), wxTE_MULTILINE | wxTE_AUTO_URL, valTexto);
    boxHorizontal->Add(ctrlTexto, wxSizerFlags().Border());
    boxVertical->Add(boxHorizontal, wxSizerFlags().Border(wxTOP).Right());

    boxHorizontal = new wxBoxSizer(wxHORIZONTAL);

    boxHorizontal->Add(CreateStdDialogButtonSizer(wxOK | wxCANCEL), wxSizerFlags().Border());
    boxHorizontal->Add(new wxButton(this, idLoad, wxT("&Cargar"), wxDefaultPosition, wxDefaultSize, 0), wxSizerFlags().Border());
    boxVertical->Add(boxHorizontal, wxSizerFlags().Border(wxTOP).Right());

    boxHorizontal = new wxBoxSizer(wxHORIZONTAL);

    boxHorizontal->Add(new wxButton(this, idSelectAll, wxT("&Todo"), wxDefaultPosition, wxDefaultSize, 0), wxSizerFlags().Border());
    boxHorizontal->Add(new wxButton(this, idSelectNone, wxT("&Nada"), wxDefaultPosition, wxDefaultSize, 0), wxSizerFlags().Border());
    boxVertical->Add(boxHorizontal, wxSizerFlags().Border(wxTOP).Right());

    boxHorizontal = new wxBoxSizer(wxHORIZONTAL);

    boxHorizontal->Add(new wxButton(this, idValue, wxT("&Valor"), wxDefaultPosition, wxDefaultSize, 0), wxSizerFlags().Border());
    boxHorizontal->Add(new wxButton(this, idRango, wxT("&Rango"), wxDefaultPosition, wxDefaultSize, 0), wxSizerFlags().Border());
    boxVertical->Add(boxHorizontal, wxSizerFlags().Border(wxTOP).Right());

    SetSizerAndFit(boxVertical);
}

void multilinea::OnClose(wxCloseEvent &event)
{
    datos.nLineas = ctrlTexto->GetNumberOfLines();
    ctrlTexto->SaveFile("texto.txt");
    Destroy();
}

void multilinea::OnOk(wxCommandEvent &event)
{
    int n=0;
    datos.texto = ctrlTexto->GetValue();
    datos.nLineas = ctrlTexto->GetNumberOfLines();
    datos.nLineas = n;
    ctrlTexto->SaveFile("texto.txt");
    Destroy();
}

void multilinea::OnCargar(wxCommandEvent &event)
{
    ctrlTexto->LoadFile("texto.txt");
}

void multilinea::OnTodo(wxCommandEvent &event)
{
    ctrlTexto->SelectAll();
    ctrlTexto->SetFocus();
}

void multilinea::OnNada(wxCommandEvent &event)
{
    ctrlTexto->SetFocus();
    ctrlTexto->SelectNone();
}

void multilinea::OnValue(wxCommandEvent &event)
{
    wxString val = ctrlTexto->GetValue();
    wxMessageBox(val, _T("Valor"));
}

void multilinea::OnRango(wxCommandEvent &event)
{
    wxString val = ctrlTexto->GetRange(5, 16);
    wxMessageBox(val, _T("Rango 5-16"));
}

void multilinea::OnURL(wxTextUrlEvent &event) {
    long inicio = event.GetURLStart();
    long fin = event.GetURLEnd();
    wxString url = ctrlTexto->GetRange(inicio, fin);
    wxMessageBox(url, _T("Se ha pulsado una URL"));
}
