/***************************************************************
 * Name:      wx005Main.cpp
 * Purpose:   Code for Application Frame
 * Author:    Salvador Pozo (salvador@conclase.net)
 * Created:   2024-05-09
 * Copyright: Salvador Pozo (www.conclase.net)
 * License:
 **************************************************************/

#ifdef WX_PRECOMP
#include "wx_pch.h"
#endif

#include "wx005Main.h"

//helper functions
enum wxbuildinfoformat {
    short_f, long_f };

wxString wxbuildinfo(wxbuildinfoformat format)
{
    wxString wxbuild(wxVERSION_STRING);

    if (format == long_f )
    {
#if defined(__WXMSW__)
        wxbuild << _T("-Windows");
#elif defined(__WXMAC__)
        wxbuild << _T("-Mac");
#elif defined(__UNIX__)
        wxbuild << _T("-Linux");
#endif

#if wxUSE_UNICODE
        wxbuild << _T("-Unicode build");
#else
        wxbuild << _T("-ANSI build");
#endif // wxUSE_UNICODE
    }

    return wxbuild;
}

BEGIN_EVENT_TABLE(wx005Frame, wxFrame)
    EVT_CLOSE(wx005Frame::OnClose)
    EVT_MENU(idMenuQuit, wx005Frame::OnQuit)
    EVT_MENU(idMenuTexto, wx005Frame::OnTexto)
    EVT_MENU(idMenuModificar, wx005Frame::OnModificar)
    EVT_MENU(idMenuMultilinea, wx005Frame::OnMultilinea)
    EVT_MENU(idMenuAutocompletar, wx005Frame::OnAutocompletar)
    EVT_MENU(idMenuAutocompletar2, wx005Frame::OnAutocompletar2)
    EVT_MENU(idMenuLimitar, wx005Frame::OnLimitar)
END_EVENT_TABLE()

wx005Frame::wx005Frame(wxFrame *frame, const wxString& title)
    : wxFrame(frame, -1, title),
      dataUsuario(_T(""), _T(""), _T("")),
      dataTexto(_T("Texto")),
      dataMultilinea(_T("Texto\nmultilínea.")),
      dataAutocompletar(_T("")),
      dataAutocompletar2(_T("")),
      dataLimitar(_T(""))
{
    // create a menu bar
    wxMenuBar* mbar = new wxMenuBar();

    wxMenu* fileMenu = new wxMenu(_T(""));
    fileMenu->Append(idMenuTexto, _T("Editar &texto"), _T("Editar texto"));
    fileMenu->Append(idMenuModificar, _T("&Modificar texto"), _T("Modificar texto"));
    fileMenu->Append(idMenuMultilinea, _T("&Texto multilínea"), _T("Modificar texto multilínea"));
    fileMenu->Append(idMenuAutocompletar, _T("&Autocompletar simple"), _T("Texto autocompletado simple"));
    fileMenu->Append(idMenuAutocompletar2, _T("A&utocompletar"), _T("Texto autocompletado"));
    fileMenu->Append(idMenuLimitar, _T("&Limitar texto"), _T("Limitar número de caracteres"));
    fileMenu->Append(-1, _T(""), _T(""), wxITEM_SEPARATOR);
    fileMenu->Append(idMenuQuit, _T("&Quit\tAlt-F4"), _T("Abandonar la aplicación"));
    mbar->Append(fileMenu, _T("&Fichero"));


    SetMenuBar(mbar);

    // create a status bar with some information about the used wxWidgets version
    CreateStatusBar(2);
    SetStatusText(_T("Ejemplos de edición de texto"),0);
    SetStatusText(wxbuildinfo(short_f), 1);
}


wx005Frame::~wx005Frame()
{
}

void wx005Frame::OnClose(wxCloseEvent &event)
{
    Destroy();
}

void wx005Frame::OnQuit(wxCommandEvent &event)
{
    Destroy();
}

void wx005Frame::OnTexto(wxCommandEvent &event)
{
    wxString cad;
    editarUsuario *dlg = new editarUsuario(this, dataUsuario);
    dlg->ShowModal();

    cad << "Nombre: " << dataUsuario.nombre << "\n";
    cad << "Email: " << dataUsuario.email << "\n";
    cad << "Telefono: " << dataUsuario.telefono;

    wxMessageBox(cad, _T("Respuesta"));
}

void wx005Frame::OnModificar(wxCommandEvent &event)
{
    wxString cad;
    leerModificar *dlg = new leerModificar(this, dataTexto);
    dlg->ShowModal();

    cad << "Texto: " << dataTexto.texto;

    wxMessageBox(cad, _T("Respuesta"));
}

void wx005Frame::OnMultilinea(wxCommandEvent &event)
{
    wxString cad;
    multilinea *dlg = new multilinea(this, dataMultilinea);
    dlg->ShowModal();

    cad << _T("Texto: ") << dataMultilinea.texto;
    cad << _T("\nNúmero de líneas: ") << dataMultilinea.nLineas;

    wxMessageBox(cad, _T("Respuesta"));
}

void wx005Frame::OnAutocompletar(wxCommandEvent &event)
{
    wxString cad;
    autocompletar *dlg = new autocompletar(this, dataAutocompletar);
    dlg->ShowModal();

    cad << _T("Color: ") << dataAutocompletar.texto;

    wxMessageBox(cad, _T("Respuesta"));
}

void wx005Frame::OnAutocompletar2(wxCommandEvent &event)
{
    wxString cad;
    autocompletar2 *dlg = new autocompletar2(this, dataAutocompletar2);
    dlg->ShowModal();

    cad << _T("Palabra: ") << dataAutocompletar2.texto;

    wxMessageBox(cad, _T("Respuesta"));
}

void wx005Frame::OnLimitar(wxCommandEvent& event)
{
    wxString cad;
    textoLimitado *dlg = new textoLimitado(this, dataLimitar);
    dlg->ShowModal();

    cad << _T("Texto: ") << dataLimitar.texto;

    wxMessageBox(cad, _T("Respuesta"));
}
